@@ -252,11 +252,13 @@ class cognet:
             raise ValueError("load_data first!")
 
     def set_poles(self,
-                POLEFILE,
-                pole_1,
-                pole_2,
-                steps=0,
-                mutable=False):
+                  POLEFILE,
+                  pole_1,
+                  pole_2,
+                  steps=0,
+                  mutable=False,
+                  VERBOSE=False
+                  ):
         '''set the poles and samples such that the samples contain features in poles
 
         Args:
@@ -265,6 +267,7 @@ class cognet:
           mutable (boolean): Whether or not to set poles as the only mutable_vars
           pole_1 (str): column name for first pole to use
           pole_2 (str): column name for second pole to use
+          VERBOSE (bool): boolean flag prints number of pole features not found in sample features if True
         '''
         invalid_count = 0
         if all(x is not None for x in [self.samples, self.qnet]):
@@ -288,18 +291,19 @@ class cognet:
             for x in self.poles.columns:
                 if x not in self.samples.columns:
                     invalid_count += 1
-                    self.samples[x]=np.nan
+                    self.samples[x]=''
 
             self.samples = pd.concat([self.samples,self.features], axis=0)
             self.all_samples = self.samples
-            self.samples_as_strings = self.samples[self.cols].fillna('').values.astype(str)[:]
+            self.samples_as_strings = self.samples[self.cols].replace('nan',np.nan).fillna('').values.astype(str)[:]
             
             if mutable:
                 self.mutable_vars=[x for x in self.cols if x in self.poles.columns]
         elif self.samples is None:
             raise ValueError("load_data first!")
-        
-        print("{} pole features not found in sample features".format(invalid_count))
+
+        if VERBOSE:
+            print("{} pole features not found in sample features".format(invalid_count))
 
     def distance(self,
                 sample1,
@@ -466,8 +470,8 @@ class cognet:
         polar_arraydata = self.polar_features[self.cols].fillna('').values.astype(str)[:]
         samples_ = []
         for vector in polar_arraydata:
-            bp = self.getBaseFrequency(vector)
-            sample = qsample(vector, self.qnet, nsteps, baseline_prob=bp)
+            #bp = self.getBaseFrequency(vector)
+            sample = qsampling(vector, nsteps)#, baseline_prob=bp)
             samples_.append(sample)
         samples_ = np.array(samples_)
         self.polar_matrix = qdistance_matrix(samples_, samples_, self.qnet, self.qnet)
@@ -502,7 +506,7 @@ class cognet:
             EFILE = out_dir + PREF + '_E_' +yr
             DFILE = out_dir + PREF + '_D_' +yr
 
-            pd.read_csv(FILE, index_col=0).to_csv(DATAFILE,sep=' ',header=None,index=None)
+            pd.read_csv(FILE, header=None).to_csv(DATAFILE,sep=' ',header=None,index=None)
             STR=EMBED+' -f '+DATAFILE+' -E '+EFILE+' -D '+DFILE
             subprocess.call(STR,shell=True)
             if pca_model:
