@@ -31,7 +31,7 @@ class model:
         if num_None == 0:
             raise ValueError("input either samples and features or data object, not both!")
         elif data_obj is not None:
-            featurenames, samples=data_obj.train() # returns the training data
+            featurenames, samples=data_obj.samples() # returns the training data
             self.immutable_vars, self.mutable_vars = data_obj.immutable_vars, data_obj.mutable_vars
         elif num_None > 1:
             raise ValueError("input both samples and features or data object!")
@@ -52,18 +52,23 @@ class model:
         save_qnet(self.myQnet, file_path)
     
     def load(self,
-             file_path):
+             file_path,
+             VERBOSE=False):
         """load Qnet from file
 
         Args:
           file_path (str): path to Qnet savefile
+          VERBOSE (bool): boolean to turn on verbose
 
         Returns:
           [Qnet]: Qnet object
         """
-        print("updating")
+        if VERBOSE:
+            print("loading..")
         self.myQnet = load_qnet(file_path)
         self.features = self.myQnet.feature_names
+        if VERBOSE:
+            print("done")
         return self.myQnet
 
     def export_dot(self,
